==> tbb-2020.3.txz: usr/local/share/doc/tbb/files_dup.js <==
var files_dup =
[
    [ "_aggregator_impl.h", "a00086.html", [
      [ "aggregated_operation", "a02558.html", "a02558" ],
      [ "aggregator_generic", "a02562.html", "a02562" ],
      [ "aggregator", "a02566.html", "a02566" ],
      [ "aggregating_functor", "a02570.html", "a02570" ]
    ] ],
    [ "_allocator_traits.h", "a00089.html", "a00089" ],
    [ "_concurrent_queue_impl.h", "a00092.html", "a00092" ],
    [ "_concurrent_skip_list_impl.h", "a00095.html", "a00095" ],
    [ "_concurrent_unordered_impl.h", "a00098.html", "a00098" ],
    [ "_deprecated_header_message_guard.h", "a00101.html", "a00101" ],
    [ "_flow_graph_async_msg_impl.h", "a00104.html", "a00104" ],
    [ "_flow_graph_body_impl.h", "a00107.html", "a00107" ],
    [ "_flow_graph_cache_impl.h", "a00110.html", "a00110" ],
    [ "_flow_graph_impl.h", "a00113.html", "a00113" ],
    [ "_flow_graph_indexer_impl.h", "a00116.html", "a00116" ],
    [ "_flow_graph_item_buffer_impl.h", "a00119.html", "a00119" ],
    [ "_flow_graph_join_impl.h", "a00122.html", "a00122" ],
    [ "_flow_graph_node_impl.h", "a00125.html", "a00125" ],
    [ "_flow_graph_node_set_impl.h", "a00128.html", "a00128" ],
    [ "_flow_graph_nodes_deduction.h", "a00131.html", null ],
    [ "_flow_graph_streaming_node.h", "a00134.html", "a00134" ],
    [ "_flow_graph_tagged_buffer_impl.h", "a00137.html", "a00137" ],
    [ "_flow_graph_trace_impl.h", "a00140.html", "a00140" ],
    [ "_flow_graph_types_impl.h", "a00143.html", "a00143" ],
    [ "_mutex_padding.h", "a00146.html", "a00146" ],
    [ "_node_handle_impl.h", "a00149.html", [
      [ "split_ordered_list", "a02702.html", "a02702" ],
      [ "concurrent_unordered_base", "a02706.html", "a02706" ],
      [ "concurrent_skip_list", "a02682.html", "a02682" ],
      [ "node_handle_base", "a03558.html", "a03558" ],
      [ "node_handle", "a03562.html", "a03562" ],
      [ "node_handle< Key, Key, Node, Allocator >", "a03566.html", "a03566" ]
    ] ],
    [ "_range_iterator.h", "a00152.html", "a00152" ],
    [ "_tbb_hash_compare_impl.h", "a00155.html", "a00155" ],
    [ "_tbb_strings.h", "a00158.html", null ],
    [ "_tbb_trace_impl.h", "a00161.html", "a00161" ],
    [ "_tbb_windef.h", "a00164.html", "a00164" ],
    [ "_template_helpers.h", "a00167.html", "a00167" ],
    [ "_warning_suppress_disable_notice.h", "a00170.html", null ],
    [ "_warning_suppress_enable_notice.h", "a00173.html", null ],
    [ "_x86_eliding_mutex_impl.h", "a00176.html", null ],
    [ "_x86_rtm_rw_mutex_impl.h", "a00179.html", null ],
    [ "aggregator.h", "a00008.html", "a00008" ],
    [ "aligned_space.h", "a00011.html", "a00011" ],
    [ "arena.cpp", "a00353.html", "a00353" ],
    [ "arena.h", "a00356.html", [
      [ "arena_base", "a04614.html", "a04614" ],
      [ "arena", "a04618.html", "a04618" ]
    ] ],
    [ "atomic.h", "a00014.html", "a00014" ],
    [ "atomic_support.c", "a00404.html", null ],
    [ "blocked_range.h", "a00017.html", [
      [ "blocked_rangeNd_impl", "a01250.html", null ]
    ] ],
    [ "blocked_range2d.h", "a00020.html", null ],
    [ "blocked_range3d.h", "a00023.html", null ],
    [ "blocked_rangeNd.h", "a00026.html", null ],
    [ "cache_aligned_allocator.cpp", "a00359.html", "a00359" ],
    [ "cache_aligned_allocator.h", "a00029.html", "a00029" ],
    [ "cilk-tbb-interop.h", "a00362.html", "a00362" ],
    [ "co_context.h", "a00365.html", "a00365" ],
    [ "combinable.h", "a00032.html", "a00032" ],
    [ "concurrent_hash_map.cpp", "a00368.html", [
      [ "hash_map_segment_base", "a04638.html", "a04638" ]
    ] ],
    [ "concurrent_hash_map.h", "a00038.html", "a00038" ],
    [ "concurrent_lru_cache.h", "a00041.html", "a00041" ],
    [ "concurrent_map.h", "a00044.html", "a00044" ],
    [ "concurrent_monitor.cpp", "a00371.html", null ],
    [ "concurrent_monitor.h", "a00374.html", "a00374" ],
    [ "concurrent_priority_queue.h", "a00047.html", "a00047" ],
    [ "concurrent_queue.cpp", "a00377.html", "a00377" ],
    [ "concurrent_queue.h", "a00050.html", "a00050" ],
    [ "concurrent_set.h", "a00053.html", "a00053" ],
    [ "concurrent_unordered_map.h", "a00056.html", "a00056" ],
    [ "concurrent_unordered_set.h", "a00059.html", "a00059" ],
    [ "concurrent_vector.cpp", "a00380.html", [
      [ "helper", "a04678.html", "a04678" ],
      [ "segment_not_used_predicate", "a04682.html", "a04682" ],
      [ "init_body", "a04686.html", "a04686" ],
      [ "safe_init_body", "a04690.html", "a04690" ],
      [ "destroy_body", "a04694.html", "a04694" ]
    ] ],
    [ "concurrent_vector.h", "a00062.html", "a00062" ],
    [ "condition_variable.cpp", "a00383.html", null ],
    [ "critical_section.cpp", "a00386.html", null ],
    [ "critical_section.h", "a00065.html", "a00065" ],
    [ "custom_scheduler.h", "a00389.html", [
      [ "DefaultSchedulerTraits", "a04698.html", "a04698" ],
      [ "IntelSchedulerTraits", "a04702.html", "a04702" ],
      [ "custom_scheduler", "a04706.html", "a04706" ]
    ] ],
    [ "disable_warnings.h", "a00527.html", null ],
    [ "dynamic_link.cpp", "a00392.html", "a00392" ],
    [ "dynamic_link.h", "a00395.html", "a00395" ],
    [ "enumerable_thread_specific.h", "a00068.html", "a00068" ],
    [ "flow_graph.h", "a00071.html", "a00071" ],
    [ "flow_graph_abstractions.h", "a00074.html", [
      [ "graph_proxy", "a02450.html", "a02450" ],
      [ "receiver_gateway", "a02454.html", "a02454" ]
    ] ],
    [ "flow_graph_opencl_node.h", "a00077.html", "a00077" ],
    [ "gcc_arm.h", "a00185.html", "a00185" ],
    [ "gcc_generic.h", "a00188.html", "a00188" ],
    [ "gcc_ia32_common.h", "a00191.html", "a00191" ],
    [ "gcc_itsx.h", "a00194.html", "a00194" ],
    [ "global_control.h", "a00080.html", [
      [ "global_control", "a02554.html", "a02554" ]
    ] ],
    [ "governor.cpp", "a00398.html", "a00398" ],
    [ "governor.h", "a00401.html", [
      [ "governor", "a04714.html", "a04714" ]
    ] ],
    [ "ibm_aix51.h", "a00197.html", "a00197" ],
    [ "icc_generic.h", "a00200.html", "a00200" ],
    [ "info.h", "a00083.html", null ],
    [ "intrusive_list.h", "a00407.html", [
      [ "intrusive_list_node", "a04718.html", "a04718" ],
      [ "intrusive_list_base", "a04722.html", "a04722" ],
      [ "iterator_impl", "a04726.html", "a04726" ],
      [ "memptr_intrusive_list", "a04730.html", "a04730" ],
      [ "intrusive_list", "a04734.html", "a04734" ]
    ] ],
    [ "iterators.h", "a00182.html", null ],
    [ "itt_notify.cpp", "a00410.html", "a00410" ],
    [ "itt_notify.h", "a00413.html", "a00413" ],
    [ "ittnotify.h", "a00530.html", "a00530" ],
    [ "legacy/ittnotify.h", "a06508.html", "a06508" ],
    [ "ittnotify_config.h", "a00533.html", "a00533" ],
    [ "ittnotify_static.c", "a00536.html", "a00536" ],
    [ "ittnotify_static.h", "a00539.html", "a00539" ],
    [ "ittnotify_types.h", "a00542.html", "a00542" ],
    [ "linux_common.h", "a00203.html", "a00203" ],
    [ "linux_ia32.h", "a00206.html", "a00206" ],
    [ "linux_ia64.h", "a00209.html", "a00209" ],
    [ "linux_intel64.h", "a00212.html", "a00212" ],
    [ "mac_ppc.h", "a00215.html", "a00215" ],
    [ "macos_common.h", "a00218.html", "a00218" ],
    [ "mailbox.h", "a00416.html", [
      [ "task_proxy", "a04738.html", "a04738" ],
      [ "unpadded_mail_outbox", "a04742.html", "a04742" ],
      [ "mail_outbox", "a04746.html", "a04746" ],
      [ "mail_inbox", "a04750.html", "a04750" ]
    ] ],
    [ "market.cpp", "a00419.html", "a00419" ],
    [ "market.h", "a00422.html", [
      [ "market", "a04754.html", "a04754" ]
    ] ],
    [ "memory_pool.h", "a00242.html", "a00242" ],
    [ "mic_common.h", "a00221.html", "a00221" ],
    [ "msvc_armv7.h", "a00224.html", "a00224" ],
    [ "msvc_ia32_common.h", "a00227.html", "a00227" ],
    [ "mutex.cpp", "a00425.html", null ],
    [ "mutex.h", "a00245.html", "a00245" ],
    [ "null_mutex.h", "a00248.html", [
      [ "scoped_lock", "a03826.html", "a03826" ]
    ] ],
    [ "null_rw_mutex.h", "a00251.html", [
      [ "scoped_lock", "a03834.html", "a03834" ]
    ] ],
    [ "observer_proxy.cpp", "a00428.html", null ],
    [ "observer_proxy.h", "a00431.html", null ],
    [ "parallel_do.h", "a00254.html", "a00254" ],
    [ "serial/tbb/parallel_for.h", "a06511.html", "a06511" ],
    [ "tbb/parallel_for.h", "a06514.html", "a06514" ],
    [ "parallel_for_each.h", "a00257.html", "a00257" ],
    [ "parallel_invoke.h", "a00260.html", "a00260" ],
    [ "parallel_reduce.h", "a00263.html", "a00263" ],
    [ "parallel_scan.h", "a00266.html", "a00266" ],
    [ "parallel_sort.h", "a00269.html", "a00269" ],
    [ "parallel_while.h", "a00272.html", "a00272" ],
    [ "partitioner.h", "a00275.html", "a00275" ],
    [ "pipeline.cpp", "a00434.html", [
      [ "task_info", "a04758.html", "a04758" ],
      [ "input_buffer", "a04762.html", "a04762" ],
      [ "stage_task", "a04766.html", "a04766" ],
      [ "pipeline_root_task", "a04770.html", "a04770" ],
      [ "pipeline_cleaner", "a04774.html", "a04774" ]
    ] ],
    [ "pipeline.h", "a00278.html", "a00278" ],
    [ "ppl.h", "a00035.html", "a00035" ],
    [ "private_server.cpp", "a00437.html", "a00437" ],
    [ "queuing_mutex.cpp", "a00440.html", null ],
    [ "queuing_mutex.h", "a00281.html", "a00281" ],
    [ "queuing_rw_mutex.cpp", "a00443.html", "a00443" ],
    [ "queuing_rw_mutex.h", "a00284.html", "a00284" ],
    [ "reader_writer_lock.cpp", "a00446.html", "a00446" ],
    [ "reader_writer_lock.h", "a00287.html", "a00287" ],
    [ "recursive_mutex.cpp", "a00449.html", null ],
    [ "recursive_mutex.h", "a00290.html", "a00290" ],
    [ "runtime_loader.h", "a00293.html", "a00293" ],
    [ "scalable_allocator.h", "a00296.html", "a00296" ],
    [ "scheduler.cpp", "a00452.html", "a00452" ],
    [ "scheduler.h", "a00455.html", "a00455" ],
    [ "scheduler_common.h", "a00458.html", "a00458" ],
    [ "scheduler_utility.h", "a00461.html", [
      [ "auto_empty_task", "a04822.html", "a04822" ],
      [ "fast_reverse_vector", "a04826.html", "a04826" ]
    ] ],
    [ "semaphore.cpp", "a00464.html", null ],
    [ "semaphore.h", "a00467.html", "a00467" ],
    [ "spin_mutex.cpp", "a00470.html", null ],
    [ "spin_mutex.h", "a00299.html", "a00299" ],
    [ "spin_rw_mutex.cpp", "a00473.html", "a00473" ],
    [ "spin_rw_mutex.h", "a00302.html", "a00302" ],
    [ "sunos_sparc.h", "a00230.html", "a00230" ],
    [ "task.cpp", "a00476.html", "a00476" ],
    [ "task.h", "a00305.html", "a00305" ],
    [ "task_arena.h", "a00308.html", "a00308" ],
    [ "task_group.h", "a00311.html", "a00311" ],
    [ "task_group_context.cpp", "a00479.html", null ],
    [ "task_scheduler_init.h", "a00314.html", "a00314" ],
    [ "task_scheduler_observer.h", "a00317.html", "a00317" ],
    [ "task_stream.h", "a00482.html", "a00482" ],
    [ "task_stream_extended.h", "a00485.html", "a00485" ],
    [ "tbb.h", "a00320.html", "a00320" ],
    [ "tbb_allocator.h", "a00323.html", "a00323" ],
    [ "tbb_annotate.h", "a00005.html", null ],
    [ "tbb_assert_impl.h", "a00488.html", "a00488" ],
    [ "tbb_bind.cpp", "a00491.html", "a00491" ],
    [ "tbb_config.h", "a00326.html", "a00326" ],
    [ "tbb_disable_exceptions.h", "a00329.html", "a00329" ],
    [ "tbb_environment.h", "a00494.html", "a00494" ],
    [ "tbb_exception.h", "a00332.html", "a00332" ],
    [ "tbb_machine.h", "a00335.html", "a00335" ],
    [ "tbb_main.cpp", "a00497.html", "a00497" ],
    [ "tbb_main.h", "a00500.html", "a00500" ],
    [ "tbb_misc.cpp", "a00503.html", "a00503" ],
    [ "tbb_misc.h", "a00506.html", "a00506" ],
    [ "tbb_misc_ex.cpp", "a00509.html", null ],
    [ "tbb_profiling.h", "a00338.html", "a00338" ],
    [ "tbb_statistics.cpp", "a00512.html", null ],
    [ "tbb_statistics.h", "a00515.html", "a00515" ],
    [ "tbb_stddef.h", "a00341.html", "a00341" ],
    [ "tbb_thread.cpp", "a00518.html", "a00518" ],
    [ "tbb_thread.h", "a00344.html", "a00344" ],
    [ "tbb_version.h", "a00521.html", "a00521" ],
    [ "tbbmalloc_proxy.h", "a00347.html", "a00347" ],
    [ "tick_count.h", "a00350.html", "a00350" ],
    [ "tls.h", "a00524.html", "a00524" ],
    [ "windows_api.h", "a00233.html", null ],
    [ "windows_ia32.h", "a00236.html", "a00236" ],
    [ "windows_intel64.h", "a00239.html", "a00239" ],
    [ "x86_rtm_rw_mutex.cpp", "a00545.html", null ]
];

==> tbb-2020.3_1.txz: usr/local/share/doc/tbb/files_dup.js <==
var files_dup =
[
    [ "_aggregator_impl.h", "a00086.html", [
      [ "aggregated_operation", "a02094.html", "a02094" ],
      [ "aggregator_generic", "a02098.html", "a02098" ],
      [ "aggregator", "a02102.html", "a02102" ],
      [ "aggregating_functor", "a02106.html", "a02106" ]
    ] ],
    [ "_allocator_traits.h", "a00089.html", "a00089" ],
    [ "_concurrent_queue_impl.h", "a00092.html", "a00092" ],
    [ "_concurrent_skip_list_impl.h", "a00095.html", "a00095" ],
    [ "_concurrent_unordered_impl.h", "a00098.html", "a00098" ],
    [ "_deprecated_header_message_guard.h", "a00101.html", "a00101" ],
    [ "_flow_graph_async_msg_impl.h", "a00104.html", [
      [ "async_storage", "a02270.html", "a02270" ],
      [ "async_msg", "a02274.html", "a02274" ]
    ] ],
    [ "_flow_graph_body_impl.h", "a00107.html", "a00107" ],
    [ "_flow_graph_cache_impl.h", "a00110.html", [
      [ "node_cache", "a02406.html", "a02406" ],
      [ "predecessor_cache", "a02410.html", "a02410" ],
      [ "reservable_predecessor_cache", "a02414.html", "a02414" ],
      [ "successor_cache", "a02418.html", "a02418" ],
      [ "successor_cache< continue_msg, M >", "a02422.html", "a02422" ],
      [ "broadcast_cache", "a02426.html", "a02426" ],
      [ "round_robin_cache", "a02430.html", "a02430" ]
    ] ],
    [ "_flow_graph_impl.h", "a00113.html", "a00113" ],
    [ "_flow_graph_indexer_impl.h", "a00116.html", "a00116" ],
    [ "_flow_graph_item_buffer_impl.h", "a00119.html", [
      [ "item_buffer", "a02554.html", "a02554" ],
      [ "reservable_item_buffer", "a02558.html", "a02558" ]
    ] ],
    [ "_flow_graph_join_impl.h", "a00122.html", "a00122" ],
    [ "_flow_graph_node_impl.h", "a00125.html", "a00125" ],
    [ "_flow_graph_node_set_impl.h", "a00128.html", null ],
    [ "_flow_graph_nodes_deduction.h", "a00131.html", null ],
    [ "_flow_graph_streaming_node.h", "a00134.html", "a00134" ],
    [ "_flow_graph_tagged_buffer_impl.h", "a00137.html", [
      [ "buffer_element_type", "a02878.html", "a02878" ],
      [ "hash_buffer", "a02882.html", "a02882" ],
      [ "DoCleanup", "a02886.html", "a02886" ]
    ] ],
    [ "_flow_graph_trace_impl.h", "a00140.html", "a00140" ],
    [ "_flow_graph_types_impl.h", "a00143.html", "a00143" ],
    [ "_mutex_padding.h", "a00146.html", "a00146" ],
    [ "_node_handle_impl.h", "a00149.html", [
      [ "node_handle_base", "a03094.html", "a03094" ],
      [ "node_handle", "a03098.html", "a03098" ],
      [ "node_handle< Key, Key, Node, Allocator >", "a03102.html", "a03102" ]
    ] ],
    [ "_range_iterator.h", "a00152.html", "a00152" ],
    [ "_tbb_hash_compare_impl.h", "a00155.html", "a00155" ],
    [ "_tbb_strings.h", "a00158.html", null ],
    [ "_tbb_trace_impl.h", "a00161.html", "a00161" ],
    [ "_tbb_windef.h", "a00164.html", "a00164" ],
    [ "_template_helpers.h", "a00167.html", "a00167" ],
    [ "_warning_suppress_disable_notice.h", "a00170.html", null ],
    [ "_warning_suppress_enable_notice.h", "a00173.html", null ],
    [ "_x86_eliding_mutex_impl.h", "a00176.html", null ],
    [ "_x86_rtm_rw_mutex_impl.h", "a00179.html", null ],
    [ "aggregator.h", "a00008.html", "a00008" ],
    [ "aligned_space.h", "a00011.html", "a00011" ],
    [ "arena.cpp", "a00353.html", "a00353" ],
    [ "arena.h", "a00356.html", [
      [ "arena_base", "a04150.html", "a04150" ],
      [ "arena", "a04154.html", "a04154" ]
    ] ],
    [ "atomic.h", "a00014.html", "a00014" ],
    [ "atomic_support.c", "a00404.html", null ],
    [ "blocked_range.h", "a00017.html", null ],
    [ "blocked_range2d.h", "a00020.html", null ],
    [ "blocked_range3d.h", "a00023.html", null ],
    [ "blocked_rangeNd.h", "a00026.html", null ],
    [ "cache_aligned_allocator.cpp", "a00359.html", "a00359" ],
    [ "cache_aligned_allocator.h", "a00029.html", "a00029" ],
    [ "cilk-tbb-interop.h", "a00362.html", "a00362" ],
    [ "co_context.h", "a00365.html", "a00365" ],
    [ "combinable.h", "a00032.html", "a00032" ],
    [ "concurrent_hash_map.cpp", "a00368.html", [
      [ "hash_map_segment_base", "a04174.html", "a04174" ]
    ] ],
    [ "concurrent_hash_map.h", "a00038.html", "a00038" ],
    [ "concurrent_lru_cache.h", "a00041.html", "a00041" ],
    [ "concurrent_map.h", "a00044.html", "a00044" ],
    [ "concurrent_monitor.cpp", "a00371.html", null ],
    [ "concurrent_monitor.h", "a00374.html", "a00374" ],
    [ "concurrent_priority_queue.h", "a00047.html", "a00047" ],
    [ "concurrent_queue.cpp", "a00377.html", "a00377" ],
    [ "concurrent_queue.h", "a00050.html", "a00050" ],
    [ "concurrent_set.h", "a00053.html", "a00053" ],
    [ "concurrent_unordered_map.h", "a00056.html", "a00056" ],
    [ "concurrent_unordered_set.h", "a00059.html", "a00059" ],
    [ "concurrent_vector.cpp", "a00380.html", [
      [ "helper", "a04214.html", "a04214" ],
      [ "segment_not_used_predicate", "a04218.html", "a04218" ],
      [ "init_body", "a04222.html", "a04222" ],
      [ "safe_init_body", "a04226.html", "a04226" ],
      [ "destroy_body", "a04230.html", "a04230" ]
    ] ],
    [ "concurrent_vector.h", "a00062.html", "a00062" ],
    [ "condition_variable.cpp", "a00383.html", null ],
    [ "critical_section.cpp", "a00386.html", null ],
    [ "critical_section.h", "a00065.html", "a00065" ],
    [ "custom_scheduler.h", "a00389.html", [
      [ "DefaultSchedulerTraits", "a04234.html", "a04234" ],
      [ "IntelSchedulerTraits", "a04238.html", "a04238" ],
      [ "custom_scheduler", "a04242.html", "a04242" ]
    ] ],
    [ "disable_warnings.h", "a00527.html", null ],
    [ "dynamic_link.cpp", "a00392.html", "a00392" ],
    [ "dynamic_link.h", "a00395.html", "a00395" ],
    [ "enumerable_thread_specific.h", "a00068.html", "a00068" ],
    [ "flow_graph.h", "a00071.html", "a00071" ],
    [ "flow_graph_abstractions.h", "a00074.html", [
      [ "graph_proxy", "a01986.html", "a01986" ],
      [ "receiver_gateway", "a01990.html", "a01990" ]
    ] ],
    [ "flow_graph_opencl_node.h", "a00077.html", "a00077" ],
    [ "gcc_arm.h", "a00185.html", "a00185" ],
    [ "gcc_generic.h", "a00188.html", "a00188" ],
    [ "gcc_ia32_common.h", "a00191.html", "a00191" ],
    [ "gcc_itsx.h", "a00194.html", "a00194" ],
    [ "global_control.h", "a00080.html", [
      [ "global_control", "a02090.html", "a02090" ]
    ] ],
    [ "governor.cpp", "a00398.html", "a00398" ],
    [ "governor.h", "a00401.html", [
      [ "governor", "a04250.html", "a04250" ]
    ] ],
    [ "ibm_aix51.h", "a00197.html", "a00197" ],
    [ "icc_generic.h", "a00200.html", "a00200" ],
    [ "info.h", "a00083.html", null ],
    [ "intrusive_list.h", "a00407.html", [
      [ "intrusive_list_node", "a04254.html", "a04254" ],
      [ "intrusive_list_base", "a04258.html", "a04258" ],
      [ "iterator_impl", "a04262.html", "a04262" ],
      [ "memptr_intrusive_list", "a04266.html", "a04266" ],
      [ "intrusive_list", "a04270.html", "a04270" ]
    ] ],
    [ "iterators.h", "a00182.html", null ],
    [ "itt_notify.cpp", "a00410.html", "a00410" ],
    [ "itt_notify.h", "a00413.html", "a00413" ],
    [ "tools_api/ittnotify.h", "a06495.html", "a06495" ],
    [ "tools_api/legacy/ittnotify.h", "a06498.html", "a06498" ],
    [ "ittnotify_config.h", "a00533.html", "a00533" ],
    [ "ittnotify_static.c", "a00536.html", "a00536" ],
    [ "ittnotify_static.h", "a00539.html", "a00539" ],
    [ "ittnotify_types.h", "a00542.html", "a00542" ],
    [ "linux_common.h", "a00203.html", "a00203" ],
    [ "linux_ia32.h", "a00206.html", "a00206" ],
    [ "linux_ia64.h", "a00209.html", "a00209" ],
    [ "linux_intel64.h", "a00212.html", "a00212" ],
    [ "mac_ppc.h", "a00215.html", "a00215" ],
    [ "macos_common.h", "a00218.html", "a00218" ],
    [ "mailbox.h", "a00416.html", [
      [ "task_proxy", "a04274.html", "a04274" ],
      [ "unpadded_mail_outbox", "a04278.html", "a04278" ],
      [ "mail_outbox", "a04282.html", "a04282" ],
      [ "mail_inbox", "a04286.html", "a04286" ]
    ] ],
    [ "market.cpp", "a00419.html", "a00419" ],
    [ "market.h", "a00422.html", [
      [ "market", "a04290.html", "a04290" ]
    ] ],
    [ "memory_pool.h", "a00242.html", "a00242" ],
    [ "mic_common.h", "a00221.html", "a00221" ],
    [ "msvc_armv7.h", "a00224.html", "a00224" ],
    [ "msvc_ia32_common.h", "a00227.html", "a00227" ],
    [ "mutex.cpp", "a00425.html", null ],
    [ "mutex.h", "a00245.html", "a00245" ],
    [ "null_mutex.h", "a00248.html", [
      [ "scoped_lock", "a03362.html", "a03362" ]
    ] ],
    [ "null_rw_mutex.h", "a00251.html", [
      [ "scoped_lock", "a03370.html", "a03370" ]
    ] ],
    [ "observer_proxy.cpp", "a00428.html", null ],
    [ "observer_proxy.h", "a00431.html", null ],
    [ "parallel_do.h", "a00254.html", "a00254" ],
    [ "serial/tbb/parallel_for.h", "a06501.html", "a06501" ],
    [ "tbb/parallel_for.h", "a06504.html", "a06504" ],
    [ "parallel_for_each.h", "a00257.html", "a00257" ],
    [ "parallel_invoke.h", "a00260.html", "a00260" ],
    [ "parallel_reduce.h", "a00263.html", "a00263" ],
    [ "parallel_scan.h", "a00266.html", "a00266" ],
    [ "parallel_sort.h", "a00269.html", "a00269" ],
    [ "parallel_while.h", "a00272.html", "a00272" ],
    [ "partitioner.h", "a00275.html", "a00275" ],
    [ "pipeline.cpp", "a00434.html", [
      [ "task_info", "a04294.html", "a04294" ],
      [ "input_buffer", "a04298.html", "a04298" ],
      [ "stage_task", "a04302.html", "a04302" ],
      [ "pipeline_root_task", "a04306.html", "a04306" ],
      [ "pipeline_cleaner", "a04310.html", "a04310" ]
    ] ],
    [ "pipeline.h", "a00278.html", "a00278" ],
    [ "ppl.h", "a00035.html", "a00035" ],
    [ "private_server.cpp", "a00437.html", "a00437" ],
    [ "queuing_mutex.cpp", "a00440.html", null ],
    [ "queuing_mutex.h", "a00281.html", "a00281" ],
    [ "queuing_rw_mutex.cpp", "a00443.html", "a00443" ],
    [ "queuing_rw_mutex.h", "a00284.html", "a00284" ],
    [ "reader_writer_lock.cpp", "a00446.html", "a00446" ],
    [ "reader_writer_lock.h", "a00287.html", "a00287" ],
    [ "recursive_mutex.cpp", "a00449.html", null ],
    [ "recursive_mutex.h", "a00290.html", "a00290" ],
    [ "runtime_loader.h", "a00293.html", "a00293" ],
    [ "scalable_allocator.h", "a00296.html", "a00296" ],
    [ "scheduler.cpp", "a00452.html", "a00452" ],
    [ "scheduler.h", "a00455.html", "a00455" ],
    [ "scheduler_common.h", "a00458.html", "a00458" ],
    [ "scheduler_utility.h", "a00461.html", [
      [ "auto_empty_task", "a04358.html", "a04358" ],
      [ "fast_reverse_vector", "a04362.html", "a04362" ]
    ] ],
    [ "semaphore.cpp", "a00464.html", null ],
    [ "semaphore.h", "a00467.html", "a00467" ],
    [ "spin_mutex.cpp", "a00470.html", null ],
    [ "spin_mutex.h", "a00299.html", "a00299" ],
    [ "spin_rw_mutex.cpp", "a00473.html", "a00473" ],
    [ "spin_rw_mutex.h", "a00302.html", "a00302" ],
    [ "sunos_sparc.h", "a00230.html", "a00230" ],
    [ "task.cpp", "a00476.html", "a00476" ],
    [ "task.h", "a00305.html", "a00305" ],
    [ "task_arena.h", "a00308.html", "a00308" ],
    [ "task_group.h", "a00311.html", "a00311" ],
    [ "task_group_context.cpp", "a00479.html", null ],
    [ "task_scheduler_init.h", "a00314.html", "a00314" ],
    [ "task_scheduler_observer.h", "a00317.html", "a00317" ],
    [ "task_stream.h", "a00482.html", "a00482" ],
    [ "task_stream_extended.h", "a00485.html", "a00485" ],
    [ "tbb.h", "a00320.html", "a00320" ],
    [ "tbb_allocator.h", "a00323.html", "a00323" ],
    [ "tbb_annotate.h", "a00005.html", null ],
    [ "tbb_assert_impl.h", "a00488.html", "a00488" ],
    [ "tbb_bind.cpp", "a00491.html", "a00491" ],
    [ "tbb_config.h", "a00326.html", "a00326" ],
    [ "tbb_disable_exceptions.h", "a00329.html", "a00329" ],
    [ "tbb_environment.h", "a00494.html", "a00494" ],
    [ "tbb_exception.h", "a00332.html", "a00332" ],
    [ "tbb_machine.h", "a00335.html", "a00335" ],
    [ "tbb_main.cpp", "a00497.html", "a00497" ],
    [ "tbb_main.h", "a00500.html", "a00500" ],
    [ "tbb_misc.cpp", "a00503.html", "a00503" ],
    [ "tbb_misc.h", "a00506.html", "a00506" ],
    [ "tbb_misc_ex.cpp", "a00509.html", null ],
    [ "tbb_profiling.h", "a00338.html", "a00338" ],
    [ "tbb_statistics.cpp", "a00512.html", null ],
    [ "tbb_statistics.h", "a00515.html", "a00515" ],
    [ "tbb_stddef.h", "a00341.html", "a00341" ],
    [ "tbb_thread.cpp", "a00518.html", "a00518" ],
    [ "tbb_thread.h", "a00344.html", "a00344" ],
    [ "tbb_version.h", "a00521.html", "a00521" ],
    [ "tbbmalloc_proxy.h", "a00347.html", "a00347" ],
    [ "tick_count.h", "a00350.html", "a00350" ],
    [ "tls.h", "a00524.html", "a00524" ],
    [ "windows_api.h", "a00233.html", null ],
    [ "windows_ia32.h", "a00236.html", "a00236" ],
    [ "windows_intel64.h", "a00239.html", "a00239" ],
    [ "x86_rtm_rw_mutex.cpp", "a00545.html", null ]
];
